# Generated by Django 3.1.2 on 2020-11-05 16:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('opcalendar', '0009_auto_20201105_0859'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event',
            name='visibility',
            field=models.CharField(choices=[('public', 'Public access'), ('member', 'Members only access')], db_index=True, default='public', max_length=7),
        ),
    ]
